@@ -186,7 +186,20 @@ def test_stub() -> None:
     assert_format(source, expected, mode)
 
 
+def test_nested_class_stub() -> None:
+    mode = replace(DEFAULT_MODE, is_pyi=True, preview=True)
+    source, expected = read_data("miscellaneous", "nested_class_stub.pyi")
+    assert_format(source, expected, mode)
+
+
 def test_power_op_newline() -> None:
     # requires line_length=0
     source, expected = read_data("miscellaneous", "power_op_newline")
     assert_format(source, expected, mode=black.Mode(line_length=0))
+
+
+def test_type_comment_syntax_error() -> None:
+    """Test that black is able to format python code with type comment syntax errors."""
+    source, expected = read_data("type_comments", "type_comment_syntax_error")
+    assert_format(source, expected)
+    black.assert_equivalent(source, expected)
